﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Web;

namespace KenticoMVC.Models
{
    public class Book : IValidatableObject
    {
        public int ID
        {
            get;
            set;
        }

        [Required]
        public string Name
        {
            get;
            set;
        }

        [Required]
        public string Author
        {
            get;
            set;
        }

        [RegularExpression(@"^http(s?)\:\/\/[0-9a-zA-Z]([-.\w]*[0-9a-zA-Z])*(:(0-9)*)*(\/?)([a-zA-Z0-9\-\.\?\,\'\/\\\+&amp;%\$#_]*)?$", 
            ErrorMessage = "Please enter a valid url")]
        [Display(Name = "Image")]

        public string ImgUrl
        {
            get;
            set;
        }

        [Required]
        [Range(1600, 2200)]
        public int Year
        {
            get;
            set;
        }
    
        public IEnumerable<ValidationResult> Validate(ValidationContext validationContext)
        {
 	        if (Year > DateTime.Now.Year)
            {
               yield return new ValidationResult("Book year cannot be in the future");
            }

            if (Year < 1600)
            {
                yield return new ValidationResult("Book is dated before book print was invented");
            }
        }
    }
}